@@ -12,7 +12,6 @@ import math
 import numpy as np
 import os
 import copy
-import datetime
 from . import array as cc_array
 from . import clock as cc_clock
 from . import maths as cc_maths
@@ -135,7 +134,6 @@ class Loader:
         print('self.n_conditions_directories =', self.n_conditions_directories)
         # print('self.conditions_directories =', self.conditions_directories)
 
-
         if self.shuffle:
             self.batches_indexes = None
         else:
@@ -192,16 +190,9 @@ class Loader:
                     self.conditions_directories_names[l][combination_directory_ebi[l]]
                     for l in range(self.L)]
                 directory_ebi = os.path.join(self.directory_root, *combination_directory_str_ebi)
-                # array_i_cv2 = cv2.imread(directory_i, cv2.IMREAD_COLOR)
-                # array_i = PIL.Image.open(directory_ebi)
-                #
-                # input_tensor_i = self.transforms(array_i)
                 self.indexes_batch[0] = i
 
                 image_ebi = PIL.Image.open(directory_ebi)
-
-                # tensor_ebi = self.transforms(image_ebi)
-                # self.tensor_batch[tuple(self.indexes_batch[0])] = tensor_ebi
                 self.tensor_batch[tuple(self.indexes_batch)] = self.transforms(image_ebi)
 
             yield [self.tensor_batch, labels_b]
@@ -215,7 +206,7 @@ class Loader:
 def train_early_stop(model, loader, criterion, optimizer, scheduler, I=10):
 
     # timer = cc_clock.Timer()
-    cc_timer = cc_clock.AllUnitsTimer()
+    cc_timer = cc_clock.Timer()
 
     for key_loader_k in loader.keys():
         if key_loader_k == 'training' or key_loader_k == 'validation':
@@ -394,7 +385,7 @@ def train_early_stop(model, loader, criterion, optimizer, scheduler, I=10):
     print()
     E = e
 
-    time_training = cc_timer.get_all_unit_time()
+    time_training = cc_timer.get_delta_time()
 
     print('Training complete in {d:s} days {h:s} hours {m:s} minutes {s:s} seconds'.format(
         d=str(time_training.days), h=str(time_training.hours),
@@ -417,9 +408,9 @@ def load_model(name_model, K=None, pretrained=False, device=None):
         template_load_string = f"model = torchvision.models.{str(name_model):s}(pretrained=pretrained)"
 
     dict_globals = {'__builtins__': None}
-    dict_locals = {'torchvision': torchvision, 'pretrained': pretrained}
+    dict_locals = {'torchvision': torchvision, 'pretrained': pretrained}  # type: dict
     exec(template_load_string, dict_globals, dict_locals)
-    model = dict_locals['model']
+    model = dict_locals['model']  # type: torchvision.models.ResNet
 
     if K is not None:
         num_ftrs = model.fc.in_features
